CREATE OR REPLACE PACKAGE BODY security_pkg
IS

   PROCEDURE set_security_context (
      p_username IN VARCHAR2,
      p_application IN VARCHAR2, 
      p_is_web_user IN VARCHAR2 DEFAULT 'Y')
   IS
   BEGIN
      --
      -- Write the user info and a flag about web user into the context area
      SYS.DBMS_SESSION.set_context ('HR_CONTEXT', 'IS_WEB_USER', p_is_web_user);
      SYS.DBMS_SESSION.set_context ('HR_CONTEXT', 'APP_USERNAME', p_username);
      --
      -- Set information into the database session. This will be visible
      -- in the V$SESSION virtual view CLIENT_INFO and ACTION columns.
      DBMS_APPLICATION_INFO.SET_CLIENT_INFO(SUBSTR(p_username, 1, 64));
      DBMS_APPLICATION_INFO.SET_ACTION(SUBSTR(p_application || ' - ' || 
         TO_CHAR(SYSDATE,'MM/DD/YYYY HH24:MI'), 1, 32));
   EXCEPTION
      WHEN OTHERS
      THEN
         RAISE_APPLICATION_ERROR(-20001, 
            'Error in SECURITY_PKG.SET_SECURITY_CONTEXT: ' || SQLERRM);
   END;

   
   FUNCTION logged_in_user
      RETURN VARCHAR2
   IS
      v_username   VARCHAR2(100);
   BEGIN   
      IF UPPER(SYS_CONTEXT('HR_CONTEXT', 'IS_WEB_USER')) = 'Y'
      THEN
         v_username := UPPER(SYS_CONTEXT('HR_CONTEXT', 'APP_USERNAME'));
      ELSE
         v_username := USER;
      END IF;
      RETURN v_username;
   EXCEPTION
      WHEN OTHERS
      THEN
         RETURN 'Error in LOGGED_IN_USER';
   END;   
   
END security_pkg;
/
